@@ -4,12 +4,13 @@ from fabric.state import output as output_level
 from ground_soil.datastucture import SettingsDict
 from beanstalk import (BEANSTALK_ROOT_PATH, BEANSTALK_GLOBAL_BASE_PATH,
                        BEANSTALK_LOCAL_BASE_PATH)
-from beanstalk.titles import section_title
+from beanstalk.console.titles import section_title
 
 
 def load_role_settings(role=None, load_again=False, default_only=False, **setting_patches):
     """Load beanstalk settings in
     """
+    # Loaded?
     env_key = 'beanstalk_settings' if not default_only else 'beanstalk_default_settings'
     if not load_again and env_key in env:
         return env[env_key]
@@ -24,19 +25,19 @@ def load_role_settings(role=None, load_again=False, default_only=False, **settin
     setting_paths = []
     default_settings_path = os.path.join(BEANSTALK_ROOT_PATH, 'default_settings/{0}_settings.py'.format(role))
     setting_paths.append(default_settings_path)
-    # Get global role settings path
+
+    # Get other's settings
     if not default_only:
+        # Get global role settings path
         global_settings_path = os.path.join(BEANSTALK_GLOBAL_BASE_PATH, '{0}_settings.py'.format(role))
         if os.path.exists(global_settings_path):
             setting_paths.append(global_settings_path)
-    # Get user role settings path
-    if not default_only:
+        # Get user role settings path
         user_settings_path = os.path.expanduser(
             os.path.join('~/.beanstalk_stack/{0}_settings.py'.format(role)))
         if os.path.exists(user_settings_path):
             setting_paths.append(user_settings_path)
-    # Get project role settings path
-    if not default_only:
+        # Get project role settings path
         project_settings_path = os.path.join(
             os.getcwd(), BEANSTALK_LOCAL_BASE_PATH, '{0}_settings.py'.format(role))
         if os.path.exists(project_settings_path):
